@@ -1,9 +1,11 @@
 use anyhow::{bail, Context, Result};
+use clap::ArgEnum;
 use console::{style, Term};
 use indicatif::{MultiProgress, ProgressBar};
 use linter::Linter;
 use log::debug;
 use path::AbsPath;
+use persistent_data::PersistentDataStore;
 use render::{render_lint_messages, render_lint_messages_json};
 use std::collections::HashMap;
 use std::collections::HashSet;
@@ -12,11 +14,14 @@ use std::sync::{Arc, Mutex};
 use std::thread;
 
 mod git;
+pub mod init;
 pub mod lint_config;
 pub mod lint_message;
 pub mod linter;
-mod log_utils;
+pub mod log_utils;
 pub mod path;
+pub mod persistent_data;
+pub mod rage;
 pub mod render;
 
 use git::get_changed_files;
@@ -26,6 +31,7 @@ use lint_message::LintMessage;
 use render::PrintedLintErrors;
 
 use crate::git::get_merge_base_with;
+use crate::render::render_lint_messages_oneline;
 
 fn group_lints_by_file(
     all_lints: &mut HashMap<Option<String>, Vec<LintMessage>>,
@@ -62,7 +68,12 @@ fn apply_patches(lint_messages: &[LintMessage]) -> Result<()> {
     Ok(())
 }
 
-pub fn do_init(linters: Vec<Linter>, dry_run: bool) -> Result<i32> {
+pub fn do_init(
+    linters: Vec<Linter>,
+    dry_run: bool,
+    persistent_data_store: &PersistentDataStore,
+    config_path: &AbsPath,
+) -> Result<i32> {
     debug!(
         "Initializing linters: {:?}",
         linters.iter().map(|l| &l.code).collect::<Vec<_>>()
@@ -72,6 +83,8 @@ pub fn do_init(linters: Vec<Linter>, dry_run: bool) -> Result<i32> {
         linter.init(dry_run)?;
     }
 
+    persistent_data_store.update_last_init(config_path)?;
+
     Ok(0)
 }
 
@@ -108,7 +121,7 @@ fn get_paths_from_file(file: AbsPath) -> Result<Vec<AbsPath>> {
 }
 
 /// Represents the set of paths the user wants to lint.
-pub enum PathsToLint {
+pub enum PathsOpt {
     /// The user didn't specify any paths, so we'll automatically determine
     /// which paths to check.
     Auto,
@@ -128,11 +141,18 @@ pub enum RevisionOpt {
     MergeBaseWith(String),
 }
 
+#[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, ArgEnum)]
+pub enum RenderOpt {
+    Default,
+    Json,
+    Oneline,
+}
+
 pub fn do_lint(
     linters: Vec<Linter>,
-    paths_to_lint: PathsToLint,
+    paths_opt: PathsOpt,
     should_apply_patches: bool,
-    render_as_json: bool,
+    render_opt: RenderOpt,
     enable_spinners: bool,
     revision_opt: RevisionOpt,
 ) -> Result<i32> {
@@ -141,8 +161,8 @@ pub fn do_lint(
         linters.iter().map(|l| &l.code).collect::<Vec<_>>()
     );
 
-    let mut files = match paths_to_lint {
-        PathsToLint::Auto => {
+    let mut files = match paths_opt {
+        PathsOpt::Auto => {
             let git_root = get_git_root()?;
             let relative_to = match revision_opt {
                 RevisionOpt::Head => None,
@@ -153,9 +173,9 @@ pub fn do_lint(
             };
             get_changed_files(&git_root, relative_to.as_deref())?
         }
-        PathsToLint::PathsCmd(paths_cmd) => get_paths_from_cmd(paths_cmd)?,
-        PathsToLint::Paths(paths) => get_paths_from_input(paths)?,
-        PathsToLint::PathsFile(file) => get_paths_from_file(file)?,
+        PathsOpt::PathsCmd(paths_cmd) => get_paths_from_cmd(paths_cmd)?,
+        PathsOpt::Paths(paths) => get_paths_from_input(paths)?,
+        PathsOpt::PathsFile(file) => get_paths_from_file(file)?,
     };
 
     // Sort and unique the files so we pass a consistent ordering to linters
@@ -229,10 +249,10 @@ pub fn do_lint(
 
     let mut stdout = Term::stdout();
 
-    let did_print = if render_as_json {
-        render_lint_messages_json(&mut stdout, &all_lints)?
-    } else {
-        render_lint_messages(&mut stdout, &all_lints)?
+    let did_print = match render_opt {
+        RenderOpt::Default => render_lint_messages(&mut stdout, &all_lints)?,
+        RenderOpt::Json => render_lint_messages_json(&mut stdout, &all_lints)?,
+        RenderOpt::Oneline => render_lint_messages_oneline(&mut stdout, &all_lints)?,
     };
 
     if should_apply_patches {
