@@ -1,20 +1,23 @@
 use std::{collections::HashSet, convert::TryFrom, io::Write};
 
 use anyhow::{Context, Result};
+use chrono::SecondsFormat;
 use clap::Parser;
 
 use lintrunner::{
     do_init, do_lint,
     init::check_init_changed,
     lint_config::{get_linters_from_config, LintRunnerConfig},
+    log_utils::setup_logger,
     path::AbsPath,
-    persistent_data::PersistentDataStore,
+    persistent_data::{ExitInfo, PersistentDataStore, RunInfo},
+    rage::do_rage,
     render::print_error,
     PathsOpt, RenderOpt, RevisionOpt,
 };
 
 #[derive(Debug, Parser)]
-#[clap(name = "lintrunner", about = "A lint runner", infer_subcommands(true))]
+#[clap(version, name = "lintrunner", infer_subcommands(true))]
 struct Args {
     /// Verbose mode (-v, or -vv to show full list of paths being linted)
     #[clap(short, long, parse(from_occurrences), global = true)]
@@ -101,10 +104,21 @@ enum SubCommand {
 
     /// Run linters. This is the default if no subcommand is provided.
     Lint,
+
+    /// Create a bug report for a past invocation of lintrunner.
+    Rage {
+        /// Choose a specific invocation to report on. 0 is the most recent run.
+        #[clap(long, short)]
+        invocation: Option<usize>,
+    },
 }
 
 fn do_main() -> Result<i32> {
     let args = Args::parse();
+
+    let config_path = AbsPath::try_from(&args.config)
+        .with_context(|| format!("Could not read lintrunner config at: '{}'", args.config))?;
+
     if args.force_color {
         console::set_colors_enabled(true);
         console::set_colors_enabled_stderr(true);
@@ -122,10 +136,18 @@ fn do_main() -> Result<i32> {
         // Any higher verbosity goes to trace.
         (_, _) => log::LevelFilter::Trace,
     };
-    env_logger::Builder::new().filter_level(log_level).init();
 
-    let config_path = AbsPath::try_from(&args.config)
-        .with_context(|| format!("Could not read lintrunner config at: '{}'", args.config))?;
+    let run_info = RunInfo {
+        args: std::env::args().collect(),
+        timestamp: chrono::Local::now().to_rfc3339_opts(SecondsFormat::Millis, true),
+    };
+    let persistent_data_store = PersistentDataStore::new(&config_path, run_info)?;
+
+    setup_logger(
+        log_level,
+        &persistent_data_store.log_file(),
+        args.force_color,
+    )?;
 
     let cmd = args.cmd.unwrap_or(SubCommand::Lint);
     let lint_runner_config = LintRunnerConfig::new(&config_path)?;
@@ -168,7 +190,6 @@ fn do_main() -> Result<i32> {
         get_linters_from_config(all_linters, skipped_linters, taken_linters, &config_path)?;
 
     let enable_spinners = args.verbose == 0 && args.output == RenderOpt::Default;
-    let persistent_data_store = PersistentDataStore::new(&config_path)?;
 
     let revision_opt = if let Some(revision) = args.revision {
         RevisionOpt::Revision(revision)
@@ -190,7 +211,7 @@ fn do_main() -> Result<i32> {
         PathsOpt::Auto
     };
 
-    match cmd {
+    let res = match cmd {
         SubCommand::Init { dry_run } => {
             // Just run initialization commands, don't actually lint.
             do_init(linters, dry_run, &persistent_data_store, &config_path)
@@ -218,7 +239,24 @@ fn do_main() -> Result<i32> {
                 revision_opt,
             )
         }
-    }
+        SubCommand::Rage { invocation } => do_rage(&persistent_data_store, invocation),
+    };
+
+    let exit_info = match &res {
+        Ok(code) => ExitInfo {
+            code: *code,
+            err: None,
+        },
+        Err(err) => ExitInfo {
+            code: 1,
+            err: Some(err.to_string()),
+        },
+    };
+
+    // Write data related to this run out to the persistent data store.
+    persistent_data_store.write_run_info(exit_info)?;
+
+    res
 }
 
 fn main() {
